@@ -147,10 +147,13 @@ class hack:
                     requests.get("https://"+site)
             while True:
              threading.Thread(target=website).start()
+    def clicker():
+    	import pyautogui
+        while True:
+            pyautogui.click()
 class cmd():
     '''def command():
     	if 1 == 1:
-            print('ASSOC          Вывод либо изменение сопоставлений по расширениям имен файлов.')
             print('ATTRIB         Отображение и изменение атрибутов файлов.')
             print('BREAK        Включение и выключение режима обработки комбинации клавиш CTRL+C.')
             print('BCDEDIT        Задает свойства в базе данных загрузки для управления начальной')
